[![PyPI version](https://badge.fury.io/py/sos-notebook.svg)](https://badge.fury.io/py/sos-notebook)
[![DOI](https://zenodo.org/badge/105826659.svg)](https://zenodo.org/badge/latestdoi/105826659)
[![Build Status](https://travis-ci.org/vatlab/sos-notebook.svg?branch=master)](https://travis-ci.org/vatlab/sos-notebook)
[![Build status](https://ci.appveyor.com/api/projects/status/nkyw7f4o97u7jl1l/branch/master?svg=true)](https://ci.appveyor.com/project/BoPeng/sos-notebook/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/9b2c7f4e9d93434b8e5a33f7f91b8172)](https://www.codacy.com/app/BoPeng/sos-notebook?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=vatlab/sos-notebook&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/github/vatlab/sos-notebook/badge.svg)](https://coveralls.io/github/vatlab/sos-notebook)

# sos-notebook
SoS Notebook. Please refer to [SoS Homepage](http://vatlab.github.io/SoS/) for details.
